// Project : K-means
// Author : Dario GENGA

#include "values_utils.h"

int random_with_min_man_value(int min, int max) {
    return (rand() % (max - min + 1)) + min;
}

/// Swap x and y values
/// \param x The first value
/// \param y The second value
void swap(int *x, int *y)
{
    int tmp = *x;
    *x = *y;
    *y = tmp;
}

float compute_euclidean_distance(float* p1, float* p2, size_t dimensions) {
    float sum = 0;
    float result = 0;

    for (size_t i = 0; i < dimensions; i++) {
        sum += pow(p1[i] - p2[i], 2);
    }
    result = sqrt(sum);
    return result;
}

float compute_manhattan_distance(float* p1, float* p2, size_t dimensions) {
    float result = 0;

    for (size_t i = 0; i < dimensions; i++) {
        result += fabs(p1[i] - p2[i]);
    }
    return result;
}

float compute_chebyshev_distance(float* p1, float* p2, size_t dimensions) {
    float result = 0;

    for (size_t i = 0; i < dimensions; i++) {
        int abs_diff = fabs(p1[i] - p2[i]);
        if (abs_diff > result) {
            result = abs_diff;
        }
    }
    return result;
}
